@@ -251,6 +251,20 @@ class _ExtractInfo:
             )
         return self._returning_named_expr
 
+    _returning_generator = None
+
+    @property
+    def returning_generator_exp(self):
+        """Does the extracted piece contains a generator expression"""
+        if self._returning_generator is None:
+            self._returning_generator = (
+                isinstance(self._parsed_extracted, ast.Module)
+                and isinstance(self._parsed_extracted.body[0], ast.Expr)
+                and isinstance(self._parsed_extracted.body[0].value, ast.GeneratorExp)
+            )
+
+        return self._returning_generator
+
 
 class _ExtractCollector:
     """Collects information needed for performing the extract"""
@@ -752,8 +766,7 @@ class _ExtractVariableParts:
 
     def get_definition(self):
         extracted = _get_single_expression_body(self.info.extracted, info=self.info)
-        result = self.info.new_name + " = " + extracted + "\n"
-        return result
+        return self.info.new_name + " = " + extracted + "\n"
 
     def get_body_pattern(self):
         return "(%s)" % self.info.extracted.strip()
@@ -1103,6 +1116,10 @@ def _get_single_expression_body(extracted, info):
     if not large_multiline:
         extracted = _join_lines(extracted)
     multiline_expression = "\n" in extracted
-    if info.returning_named_expr or (multiline_expression and not large_multiline):
+    if (
+        info.returning_named_expr
+        or info.returning_generator_exp
+        or (multiline_expression and not large_multiline)
+    ):
         extracted = "(" + extracted + ")"
     return extracted
