@@ -69,7 +69,7 @@ class MismatchedTokenError(exceptions.RopeError):
     pass
 
 
-class _PatchingASTWalker(object):
+class _PatchingASTWalker:
     def __init__(self, source, children=False):
         self.source = _Source(source)
         self.children = children
@@ -277,6 +277,7 @@ class _PatchingASTWalker(object):
         "Div": "/",
         "Mod": "%",
         "Pow": "**",
+        "MatMult": "@",
         "LShift": "<<",
         "RShift": ">>",
         "BitOr": "|",
@@ -351,34 +352,8 @@ class _PatchingASTWalker(object):
             return (node.lineno, node.col_offset)
 
         children = [node.func, "("]
-        unstarred_args = []
-        starred_and_keywords = list(node.keywords)
-        for i, arg in enumerate(node.args):
-            if hasattr(ast, "Starred") and isinstance(arg, ast.Starred):
-                starred_and_keywords.append(arg)
-            else:
-                unstarred_args.append(arg)
-        if getattr(node, "starargs", None):
-            starred_and_keywords.append(node.starargs)
-        starred_and_keywords.sort(key=_arg_sort_key)
-        children.extend(self._child_nodes(unstarred_args, ","))
-
-        # positional args come before keywords, *args comes after all
-        # positional args, and **kwargs comes last
-        if starred_and_keywords:
-            if len(children) > 2:
-                children.append(",")
-            for i, arg in enumerate(starred_and_keywords):
-                if arg == getattr(node, "starargs", None):
-                    children.append("*")
-                children.append(arg)
-                if i + 1 < len(starred_and_keywords):
-                    children.append(",")
-
-        if getattr(node, "kwargs", None):
-            if len(children) > 2:
-                children.append(",")
-            children.extend(["**", node.kwargs])
+        args = sorted([*node.args, *node.keywords], key=_arg_sort_key)
+        children.extend(self._child_nodes(args, ","))
         children.append(")")
         self._handle(node, children)
 
@@ -746,30 +721,11 @@ class _PatchingASTWalker(object):
         self._handle(node, children)
 
     def _Raise(self, node):
-        def get_python3_raise_children(node):
-            children = ["raise"]
-            if node.exc:
-                children.append(node.exc)
-            if node.cause:
-                children.append(node.cause)
-            return children
-
-        def get_python2_raise_children(node):
-            children = ["raise"]
-            if node.type:
-                children.append(node.type)
-            if node.inst:
-                children.append(",")
-                children.append(node.inst)
-            if node.tback:
-                children.append(",")
-                children.append(node.tback)
-            return children
-
-        if pycompat.PY2:
-            children = get_python2_raise_children(node)
-        else:
-            children = get_python3_raise_children(node)
+        children = ["raise"]
+        if node.exc:
+            children.append(node.exc)
+        if node.cause:
+            children.append(node.cause)
         self._handle(node, children)
 
     def _Return(self, node):
@@ -810,23 +766,18 @@ class _PatchingASTWalker(object):
         is_there_except_handler = False
         not_empty_body = True
         if len(node.finalbody) == 1:
-            if pycompat.PY2:
-                is_there_except_handler = isinstance(node.body[0], ast.TryExcept)
-                not_empty_body = not bool(len(node.body))
-            elif pycompat.PY3:
-                try:
-                    is_there_except_handler = isinstance(
-                        node.handlers[0], ast.ExceptHandler
-                    )
-                    not_empty_body = True
-                except IndexError:
-                    pass
+            try:
+                is_there_except_handler = isinstance(
+                    node.handlers[0], ast.ExceptHandler
+                )
+                not_empty_body = True
+            except IndexError:
+                pass
         children = []
         if not_empty_body or not is_there_except_handler:
             children.extend(["try", ":"])
         children.extend(node.body)
-        if pycompat.PY3:
-            children.extend(node.handlers)
+        children.extend(node.handlers)
         children.extend(["finally", ":"])
         children.extend(node.finalbody)
         self._handle(node, children)
@@ -906,11 +857,8 @@ class _PatchingASTWalker(object):
             children.extend([self.with_or_comma_context_manager, item.context_expr])
             if item.optional_vars:
                 children.extend(["as", item.optional_vars])
-        if pycompat.PY2 and COMMA_IN_WITH_PATTERN.search(self.source.source):
-            children.append(node.body[0])
-        else:
-            children.append(":")
-            children.extend(node.body)
+        children.append(":")
+        children.extend(node.body)
         self._handle(node, children)
 
     def _With(self, node):
@@ -956,7 +904,7 @@ class _PatchingASTWalker(object):
         self._handle(node, [node.value])
 
 
-class _Source(object):
+class _Source:
     def __init__(self, source):
         self.source = source
         self.offset = 0
@@ -971,7 +919,7 @@ class _Source(object):
                     self._skip_comment()
         except (ValueError, TypeError) as e:
             raise MismatchedTokenError(
-                "Token <%s> at %s cannot be matched" % (token, self._get_location())
+                "Token <{}> at {} cannot be matched".format(token, self._get_location())
             )
         self.offset = new_offset + len(token)
         return (new_offset, self.offset)
@@ -985,8 +933,8 @@ class _Source(object):
         if _Source._string_pattern is None:
             string_pattern = codeanalyze.get_string_pattern()
             formatted_string_pattern = codeanalyze.get_formatted_string_pattern()
-            original = r"(?:%s)|(?:%s)" % (string_pattern, formatted_string_pattern)
-            pattern = r"(%s)((\s|\\\n|#[^\n]*\n)*(%s))*" % (original, original)
+            original = r"(?:{})|(?:{})".format(string_pattern, formatted_string_pattern)
+            pattern = r"({})((\s|\\\n|#[^\n]*\n)*({}))*".format(original, original)
             _Source._string_pattern = re.compile(pattern)
         repattern = _Source._string_pattern
         return self._consume_pattern(repattern, end)
